@@ -14,6 +14,7 @@
 #define MAILBOX_LIST_NAME_INDEX "index"
 #define MAILBOX_LIST_NAME_NONE "none"
 
+#define MAILBOX_LIST_INDEX_DEFAULT_PREFIX "dovecot.list.index"
 #define MAILBOX_LOG_FILE_NAME "dovecot.mailbox.log"
 
 #define T_MAILBOX_LIST_ERR_NOT_FOUND(list, name) \
@@ -88,6 +89,7 @@ struct mailbox_list_vfuncs {
 	void (*notify_deinit)(struct mailbox_list_notify *notify);
 	void (*notify_wait)(struct mailbox_list_notify *notify,
 			    void (*callback)(void *context), void *context);
+	void (*notify_flush)(struct mailbox_list_notify *notify);
 };
 
 struct mailbox_list_module_register {
@@ -126,6 +128,9 @@ struct mailbox_list {
 	HASH_TABLE(uint8_t *, struct mailbox_guid_cache_rec *) guid_cache;
 	bool guid_cache_errors;
 
+	/* Last error set in mailbox_list_set_critical(). */
+	char *last_internal_error;
+
 	char *error_string;
 	enum mail_error error;
 	bool temporary_error;
@@ -135,6 +140,7 @@ struct mailbox_list {
 	unsigned int index_root_dir_created:1;
 	unsigned int guid_cache_updated:1;
 	unsigned int guid_cache_invalidated:1;
+	unsigned int last_error_is_internal:1;
 };
 
 union mailbox_list_iterate_module_context {
@@ -146,6 +152,7 @@ struct mailbox_list_iterate_context {
 	pool_t pool;
 	enum mailbox_list_iter_flags flags;
 	bool failed;
+	bool index_iteration;
 
 	struct imap_match_glob *glob;
 	struct mailbox_list_autocreate_iterate_context *autocreate_ctx;
@@ -172,6 +179,7 @@ extern struct mailbox_list_module_register mailbox_list_module_register;
 void mailbox_lists_init(void);
 void mailbox_lists_deinit(void);
 
+void mailbox_list_settings_init_defaults(struct mailbox_list_settings *set_r);
 int mailbox_list_settings_parse(struct mail_user *user, const char *data,
 				struct mailbox_list_settings *set_r,
 				const char **error_r);
@@ -203,6 +211,8 @@ int mailbox_list_delete_index_control(struct mailbox_list *list,
 void mailbox_list_iter_update(struct mailbox_list_iter_update_context *ctx,
 			      const char *name);
 int mailbox_list_iter_subscriptions_refresh(struct mailbox_list *list);
+const struct mailbox_info *
+mailbox_list_iter_default_next(struct mailbox_list_iterate_context *ctx);
 
 enum mailbox_list_file_type mailbox_list_get_file_type(const struct dirent *d);
 int mailbox_list_dirent_is_alias_symlink(struct mailbox_list *list,
@@ -224,4 +234,9 @@ void mailbox_list_set_critical(struct mailbox_list *list, const char *fmt, ...)
 void mailbox_list_set_internal_error(struct mailbox_list *list);
 bool mailbox_list_set_error_from_errno(struct mailbox_list *list);
 
+const struct mailbox_info *
+mailbox_list_iter_autocreate_filter(struct mailbox_list_iterate_context *ctx,
+				    const struct mailbox_info *_info);
+
+
 #endif
